@@ -305,7 +305,7 @@ void /*__attribute__ ((destructor))*/ gviewencoder_fini()
  *
  * returns: 1 - sample format is supported; 0 - is not supported
  */
-static int encoder_check_audio_sample_fmt(AVCodec *codec, enum AVSampleFormat sample_fmt)
+static int encoder_check_audio_sample_fmt(const AVCodec *codec, enum AVSampleFormat sample_fmt)
 {
     const enum AVSampleFormat *p = codec->sample_fmts;
 
@@ -511,10 +511,11 @@ static encoder_video_context_t *encoder_video_init(encoder_context_t *encoder_ct
     }
 
     video_codec_data->codec_context = getLoadLibsInstance()->m_avcodec_alloc_context3(video_codec_data->codec);
-
+#if !LIBAVCODEC_VER_AT_LEAST(57, 107)
     getLoadLibsInstance()->m_avcodec_get_context_defaults3(
         video_codec_data->codec_context,
         video_codec_data->codec);
+#endif
 
     if (video_codec_data->codec_context == NULL) {
         fprintf(stderr, "ENCODER: FATAL memory allocation failure (encoder_video_init): %s\n", strerror(errno));
@@ -761,7 +762,9 @@ static encoder_audio_context_t *encoder_audio_init(encoder_context_t *encoder_ct
     }
 
     audio_codec_data->codec_context = getLoadLibsInstance()->m_avcodec_alloc_context3(audio_codec_data->codec);
+#if !LIBAVCODEC_VER_AT_LEAST(57, 107)
     getLoadLibsInstance()->m_avcodec_get_context_defaults3(audio_codec_data->codec_context, audio_codec_data->codec);
+#endif
 
     if (audio_codec_data->codec_context == NULL) {
         fprintf(stderr, "ENCODER: FATAL memory allocation failure (encoder_audio_init): %s\n", strerror(errno));
